# Generated by Django 6.0.2 on 2026-03-04 02:50

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="Log",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(editable=False, null=True)),
                ("checked_at", models.DateTimeField(editable=False, null=True)),
                ("expires_at", models.DateTimeField(editable=False, null=True)),
                (
                    "token_type",
                    models.CharField(editable=False, max_length=255, null=True),
                ),
                ("uidb64", models.CharField(editable=False, max_length=255, null=True)),
                (
                    "hash",
                    models.CharField(
                        editable=False, max_length=255, null=True, unique=True
                    ),
                ),
                ("name", models.CharField(editable=False, max_length=255, null=True)),
                ("email", models.EmailField(editable=False, max_length=254, null=True)),
                ("phone", models.CharField(editable=False, max_length=255, null=True)),
                (
                    "channel",
                    models.CharField(
                        choices=[("email", "Email"), ("sms", "SMS")],
                        editable=False,
                        max_length=255,
                        null=True,
                    ),
                ),
                (
                    "send_precondition_failed",
                    models.CharField(editable=False, max_length=255, null=True),
                ),
                (
                    "check_precondition_failed",
                    models.CharField(editable=False, max_length=255, null=True),
                ),
                ("sent", models.BooleanField(default=False, editable=False)),
                ("errors", models.CharField(editable=False, max_length=255, null=True)),
                (
                    "user",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
        ),
    ]
